$wnd.rstudio.runAsyncCallback14("function Jfn(a){this.a=a}\nfunction Dzn(){iEf.call(this)}\nfunction n4h(a,b){z3h(a,Ypo,'svn_cleanup',new PH,b)}\nfunction Ffn(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Syn(a.a.b.a);rQi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.c.J.zI();break;case 2:a.a.a.c.J.AI();break;case 3:a.a.a.c.J.BI();break;case 4:Ven(a.a.a,a.b[0]);break;case 5:Wen(a.a.a,a.b[0]);break;case 6:a.a.a.c.kP();break;case 7:a.a.a.c.lP();break;case 8:a.a.a.c.mP();break;case 9:a.a.a.c.nP();break;case 10:a.a.a.c.oP();break;case 11:a.a.a.c.pP();break;case 12:Xen(a.a.a,a.b[0]);break;case 13:a.a.a.c.qP();break;case 14:Yen(a.a.a,a.b[0]);break;case 15:a.a.a.c.J.CI();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nE6c(278,1,gio);_.en=function Ifn(){Ffn((new Jfn(this)).a)};E6c(6513,1,ISn,Jfn);_.gn=function Kfn(){Ffn(this.a)};var $Zc=nQd(6513);E6c(7708,1622,cdo);_.kP=function itn(){};_.lP=function jtn(){ftn(this,false,null,Tfn(this.j.n))};_.mP=function ktn(){Mtn(this.b,Tfn(this.j.n))};_.nP=function ltn(){m1h(this.b.c,new Qtn)};_.oP=function mtn(){n1h(this.b.c,new Stn)};_.pP=function ntn(){o1h(this.b.c,new Utn)};_.qP=function otn(){ftn(this,true,null,new ypd)};E6c(6404,54,{},Dzn);_.kv=function Ezn(a){Gte(new xhn(a),true)};var P2c=nQd(6404);E6c(7716,1622,cdo);_.kP=function CAn(){n4h(this.c,new xin('SVN Cleanup','Cleaning up working directory...',750))};_.lP=function DAn(){Gte(NCn(this.a.d.a),true)};_.mP=function EAn(){kzn(this.a)};_.nP=function FAn(){y4h(this.a.g,new Bzn)};_.oP=function GAn(){y4h(this.a.g,new Dzn)};_.pP=function HAn(){};_.qP=function IAn(){zAn(this,null,new ypd)};wJn(hm)(14);\n//# sourceURL=rstudio-14.js\n")
