$wnd.rstudio.runAsyncCallback3("function DRi(a){this.a=a}\nfunction FRi(a){this.a=a}\nfunction ORi(a){this.a=a}\nfunction HBe(a,b){var c;for(c=0;c<a.q.a.length;c++){if(mpd(a.q,c).qQ==b){vEe(a.t,mRd(c));break}}}\nfunction CRi(a,b){this.c=a;this.b=TAi(a.c,Kxo,Lxo,Mxo,oUn).oI();this.a=TAi(a.c,Nxo,Oxo,Pxo,Qxo).oI();xi(b,new DRi(this),aE?aE:(aE=new vB))}\nfunction ARi(a){var b;b=BRi(a,'weaving Rnw files',a.b,TAi(a.c.c,Kxo,Lxo,Mxo,oUn));b||BRi(a,'LaTeX typesetting',a.a,TAi(a.c.c,Nxo,Oxo,Pxo,Qxo))}\nfunction yRi(a,b,c){var d;d=hMi(a.b.a);MBe(d,sDi(rRg((szf(),rzf).a)));!!b&&HBe(d,b);SBe(d,c);Gte(d,true);new CRi(a,d);(RFf()||!!$wnd.remoteDesktop)&&VFf()}\nfunction KRi(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=OYi(a.a.b.a));switch(a.c){case 1:yRi(a.a.a,null,true);break;case 2:yRi(a.a.a,a.b[0],VPd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nfunction BRi(a,b,c,d){if(zK(c)!==zK(d.oI())&&zK(d.qr())!==zK(d.oI())){d9d(2,'Project Option Unchanged','You changed the global option for '+b+iSn+d.oI()+', however the current project is still configured to use '+d.qr()+'.\\n\\nDo you want to edit the options for the current project as well?',new FRi(a),true);return true}else{return false}}\nE6c(2884,1,{},CRi);var oVb=nQd(2884);E6c(2885,1,DQn,DRi);_.so=function ERi(a){ARi(this.a)};var mVb=nQd(2885);E6c(2886,1,hTn,FRi);_.gn=function GRi(){Yee(this.a.c.a.hh)};var nVb=nQd(2886);E6c(632,1,gio);_.en=function NRi(){KRi((new ORi(this)).a)};E6c(2940,1,ISn,ORi);_.gn=function PRi(){KRi(this.a)};var pVb=nQd(2940);wJn(hm)(3);\n//# sourceURL=rstudio-3.js\n")
