[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula A"}},"key":"1D670"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula B"}},"key":"1D671"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula C"}},"key":"1D672"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula D"}},"key":"1D673"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula E"}},"key":"1D674"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula F"}},"key":"1D675"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula G"}},"key":"1D676"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula H"}},"key":"1D677"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula I"}},"key":"1D678"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula J"}},"key":"1D679"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula K"}},"key":"1D67A"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula L"}},"key":"1D67B"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula M"}},"key":"1D67C"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula N"}},"key":"1D67D"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula O"}},"key":"1D67E"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula P"}},"key":"1D67F"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula Q"}},"key":"1D680"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula R"}},"key":"1D681"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula S"}},"key":"1D682"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula T"}},"key":"1D683"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula U"}},"key":"1D684"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula V"}},"key":"1D685"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula W"}},"key":"1D686"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula X"}},"key":"1D687"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula Y"}},"key":"1D688"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula Z"}},"key":"1D689"},{"category":"Ll","mappings":{"default":{"default":"monoespacio a"}},"key":"1D68A"},{"category":"Ll","mappings":{"default":{"default":"monoespacio b"}},"key":"1D68B"},{"category":"Ll","mappings":{"default":{"default":"monoespacio c"}},"key":"1D68C"},{"category":"Ll","mappings":{"default":{"default":"monoespacio d"}},"key":"1D68D"},{"category":"Ll","mappings":{"default":{"default":"monoespacio e"}},"key":"1D68E"},{"category":"Ll","mappings":{"default":{"default":"monoespacio f"}},"key":"1D68F"},{"category":"Ll","mappings":{"default":{"default":"monoespacio g"}},"key":"1D690"},{"category":"Ll","mappings":{"default":{"default":"monoespacio h"}},"key":"1D691"},{"category":"Ll","mappings":{"default":{"default":"monoespacio i"}},"key":"1D692"},{"category":"Ll","mappings":{"default":{"default":"monoespacio j"}},"key":"1D693"},{"category":"Ll","mappings":{"default":{"default":"monoespacio k"}},"key":"1D694"},{"category":"Ll","mappings":{"default":{"default":"monoespacio l"}},"key":"1D695"},{"category":"Ll","mappings":{"default":{"default":"monoespacio m"}},"key":"1D696"},{"category":"Ll","mappings":{"default":{"default":"monoespacio n"}},"key":"1D697"},{"category":"Ll","mappings":{"default":{"default":"monoespacio o"}},"key":"1D698"},{"category":"Ll","mappings":{"default":{"default":"monoespacio p"}},"key":"1D699"},{"category":"Ll","mappings":{"default":{"default":"monoespacio q"}},"key":"1D69A"},{"category":"Ll","mappings":{"default":{"default":"monoespacio r"}},"key":"1D69B"},{"category":"Ll","mappings":{"default":{"default":"monoespacio s"}},"key":"1D69C"},{"category":"Ll","mappings":{"default":{"default":"monoespacio t"}},"key":"1D69D"},{"category":"Ll","mappings":{"default":{"default":"monoespacio u"}},"key":"1D69E"},{"category":"Ll","mappings":{"default":{"default":"monoespacio v"}},"key":"1D69F"},{"category":"Ll","mappings":{"default":{"default":"monoespacio w"}},"key":"1D6A0"},{"category":"Ll","mappings":{"default":{"default":"monoespacio x"}},"key":"1D6A1"},{"category":"Ll","mappings":{"default":{"default":"monoespacio y"}},"key":"1D6A2"},{"category":"Ll","mappings":{"default":{"default":"monoespacio z"}},"key":"1D6A3"}]
