$wnd.rstudio.runAsyncCallback16("function kJk(a){this.a=a}\nfunction JHk(a,b){this.a=a;this.b=b;lse.call(this)}\nfunction mHk(a,b){a.a=b;zIk(a.p,iHk(a,null),a.a.file_path)}\nfunction oHk(a,b){b.slide_index==0&&OVi(a.p);a.a=b;zIk(a.p,iHk(a,null),a.a.file_path)}\nfunction uHk(a){spf('Opening Presentation...',ZEd());$If(a.c,new VKf,false)}\nfunction jHk(a){var b;b=__f(new a0f(0,'Closing Presentation...'));B$h(a.n,new JHk(a,b))}\nfunction B$h(a,b){z3h(a,Ypo,'close_presentation_pane',new PH,b)}\nfunction tHk(a){var b;a.J.BI();!!a.a&&a.a.active&&(b=lpe(Oh(a.p.d).contentWindow),!(!ZRd(sTn,b)&&!ZRd('javascript:void(0)',b)))&&mHk(a,a.a)}\nfunction gJk(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=WJk(a.a.b.a);rQi(a.a,a.a.a)}switch(a.c){case 1:jHk((c=a.a.a,a.b[0],c));break;case 2:oHk(a.a.a,a.b[0]);break;case 3:a.a.a.J.zI();break;case 4:a.a.a.J.AI();break;case 5:tHk(a.a.a);break;case 6:uHk((b=a.a.a,a.b[0],b));break;case 7:a.a.a.J.CI();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nE6c(7034,32,{},JHk);_.kv=function LHk(a){var b;$If((b=this,a,b).a.c,new VKf,false)};_.jv=function KHk(a){r_f(this.b,a.a?a.a.c:a.d)};var qoc=nQd(7034);E6c(461,1,gio);_.en=function jJk(){gJk((new kJk(this)).a)};E6c(6539,1,ISn,kJk);_.gn=function lJk(){gJk(this.a)};var Poc=nQd(6539);wJn(hm)(16);\n//# sourceURL=rstudio-16.js\n")
